==> qtjambi-charts-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiCharts/QXYLegendMarker_shell.h <==
#ifndef QXYLEGENDMARKER_SHELL_H
#define QXYLEGENDMARKER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtCharts/qxylegendmarker.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qlegend.h>
#include <QtCharts/qlegendmarker.h>
#include <QtCharts/qxyseries.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qbrush.h>
#include <QtGui/qfont.h>
#include <QtGui/qpen.h>
#include <QtJambi/RegistryAPI>


class QXYLegendMarker_shell : public QXYLegendMarker, public QtJambiShellInterface
{
public:
    QXYLegendMarker_shell(QXYSeries* series0, QLegend* legend1, QObject* parent2 = nullptr);
    ~QXYLegendMarker_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QXYSeries* series() override;
    void timerEvent(QTimerEvent* event0) override;
    QLegendMarker::LegendMarkerType type() override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QXYLegendMarker_access : public QXYLegendMarker
{
    jobject __qt_series(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_type(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QXYLEGENDMARKER_SHELL_H

==> qtjambi-charts-debuginfo-windows-x64-6.5.8.jar: sources/QtJambiCharts/QXYLegendMarker_shell.h <==
#ifndef QXYLEGENDMARKER_SHELL_H
#define QXYLEGENDMARKER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qxylegendmarker.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qlegend.h>
#include <QtCharts/qlegendmarker.h>
#include <QtCharts/qxyseries.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qbrush.h>
#include <QtGui/qfont.h>
#include <QtGui/qpen.h>
#include <QtJambi/RegistryAPI>


class QXYLegendMarker_shell : public QXYLegendMarker, public QtJambiShellInterface
{
public:
    QXYLegendMarker_shell(QXYSeries* series0, QLegend* legend1, QObject* parent2 = nullptr);
    ~QXYLegendMarker_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QXYLegendMarker_mshell;
    friend class QXYLegendMarker_oshell;
};


class QXYLegendMarker_mshell : public QXYLegendMarker_shell
{
public:
    using QXYLegendMarker_shell::QXYLegendMarker_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QXYLegendMarker_oshell : public QXYLegendMarker_mshell
{
public:
    using QXYLegendMarker_mshell::QXYLegendMarker_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QXYSeries* series() override;
    void timerEvent(QTimerEvent* event0) override;
    QLegendMarker::LegendMarkerType type() override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QXYLegendMarker_access : public QXYLegendMarker
{
    jobject __qt_series(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_type(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QXYLEGENDMARKER_SHELL_H
